package WebGUI::i18n::German::Form_MatrixCompare;
use utf8;
our $I18N = {
  'costs extra' => {
    'lastUpdated' => '1228400981',
    'message' => 'Extra Kosten'
  },
  'free add on' => {
    'lastUpdated' => '1277325790',
    'message' => 'Kostenloses AddOn'
  },
  'limited' => {
    'lastUpdated' => '1277325807',
    'message' => 'Eingeschränkt'
  },
  'matrix compare' => {
    'lastUpdated' => '1234944246',
    'message' => 'Matrixvergleich'
  },
  'no' => {
    'lastUpdated' => '1251061664',
    'message' => 'Nein'
  },
  'topicName' => {
    'lastUpdated' => '1228689872',
    'message' => 'Vergleichsmatrix'
  },
  'yes' => {
    'lastUpdated' => '1228400933',
    'message' => 'Ja'
  }
}
;

1;
